@@ -67,7 +67,7 @@ class quantum_lab():
             data = response.json()
             p_status = data["jobStatus"]
             print(f"Time: {time_num} / Status: {p_status}")
-            if p_status == "Success" or p_status == "Failed"
+            if p_status == "Success" or p_status == "Failed":
                 break
             time.sleep(1)
             time_num += 1
